function [scatRc, scatErr, attRc, attErr] = itReconstrScat(n,m,thetas,...
    att,scat,nScat,nIter,indsIn,indsOut,opts)

%%--- INITIALIZATION

%--- total attenuation
attTot = att + 2*pi*scat;

%--- diffusion coefficient
diff = makeDiff(n,opts.diff);

%--- precomputation of the rotations of the total attenuation
attRot = rotateImages(attTot,thetas(1:2*m));

%--- number of configurations over which to average
nAvg = length(indsIn);

%--- allocate
scatRc = zeros(n,n,nAvg,nIter+1);
attRc = zeros(n,n,nAvg,nIter+1);
scatErr = zeros(nAvg,nIter+1);
attErr = zeros(nAvg,nIter+1);

%--- measurements with unitary scattering
measCorr = zeros(n,n,nAvg);

%%%%%%%%%%%%%%%%%%%%%%%--- MAIN

for j = 1:nAvg, %--- loop over the number of configurations (thIn,thOut)
           
    %--- precomputation of corrector (optional) based on normalized
    %--- scattering
    if opts.corr
        %--- measurements with normalized scattering for corrections
        measCorr(:,:,j) = measForRcScat(n,m,thetas,attRot,ones(n),...
            1,diff,indsIn(j),indsOut(j),0,opts.input);
        
%         figure; dispmat(measCorr(:,:,j)); pause
    end
    
    %--- initial guess for the reconstruction
    disp('Initial Guess')
        
    if opts.computeIG % compute initial guess
        %--- create measurements with forward solver
        disp(['solving fwd transport, reconstruction # ',num2str(j),...
            ' / ',num2str(nAvg)])
        M = measForRcScat(n,m,thetas,attRot,scat,nScat,diff,indsIn(j),...
            indsOut(j),0,opts.input);
        %--- first reconstruction
        scatRc(:,:,j,1) = rcScat(n,m,thetas,attTot,M,indsIn(j),...
            indsOut(j),opts.corr,measCorr(:,:,j));
    else
        scatRc(:,:,j,1) = scat;
    end
    
    scatErr(j,1) = norm(scatRc(:,:,j,1)-scat,'fro');
    attRc(:,:,j,1) = attTot-2*pi*scatRc(:,:,j,1);
    attErr(j,1) = norm(attRc(:,:,j,1)-att,'fro');
    
    %--- iterative scheme
    for it = 1:nIter,
        disp(['Iteration ',num2str(it),' / ',num2str(nIter)])
        
        % create measurements with forward transport
        M = measForRcScat(n,m,thetas,attRot,scatRc(:,:,j,it), ...
            nScat,diff,indsIn(j),indsOut(j),1,opts.input);
        
        % reconstruction formula
        
        switch opts.typeIter
            case 'initial'
                scatRc(:,:,j,it+1) = scatRc(:,:,j,1) - ...
                    rcScat(n,m,thetas,attTot,M,indsIn(j),indsOut(j),...
                    opts.corr,measCorr(:,:,j));
            case 'modified'
                scatRc(:,:,j,it+1) = (scatRc(:,:,j,1) - ...
                    rcScat(n,m,thetas,attTot,M,indsIn(j),indsOut(j),...
                    opts.corr,measCorr(:,:,j)) + scatRc(:,:,j,it))/2;
        end
        
        % intrinsic attenuation
        attRc(:,:,j,it+1) = attTot-2*pi*scatRc(:,:,j,it+1);
        
        % relative error
        scatErr(j,it+1) = norm(scatRc(:,:,j,it+1)-scat,'fro');
        attErr(j,it+1) = norm(attRc(:,:,j,it+1)-att,'fro');
    end

end

if norm(scat,'fro')>0
    scatErr = scatErr/norm(scat,'fro');
end

if norm(att,'fro')<0
    attErr = attErr/norm(att,'fro');
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%--- DISPLAY

% xs = -1+1/n:2/n:1-1/n;

if nAvg==1,
    % iterations and errors on scattering
    figure;
    for it=1:nIter,
        subplot(2,nIter+1,it); dispmat(scatRc(:,:,it));
        subplot(2,nIter+1,nIter+1+it); 
        dispmat(abs(scatRc(:,:,it+1)-scatRc(:,:,it)));
    end
    subplot(2,nIter+1,nIter+1); dispmat(scatRc(:,:,nIter+1));
    subplot(2,nIter+1,2*(nIter+1)); plot(scatErr);

%     % iterations and errors on attenuation
%     figure;
%     for it=1:nIter,
%         subplot(2,nIter+1,it); dispmat(attRc(:,:,it));
%         subplot(2,nIter+1,nIter+1+it); 
%         dispmat(abs(attRc(:,:,it+1)-attRc(:,:,it)));
%     end
%     subplot(2,nIter+1,nIter+1); dispmat(attRc(:,:,nIter+1));
%     subplot(2,nIter+1,2*(nIter+1)); plot(attErr);
    
else
    
end

% for j=1:nAvg,
%     %%--- iterations of the reconstruction
%    
%     for it = 1:nIter+1,
%         % plot the reconstruction and the error
% %         figure(50+j);
% %         subplot(2,nIter+1,it); dispmat(squeeze(scatRc(:,:,j,it)))
% %         subplot(2,nIter+1,nIter+1+it); 
% %         contourf(flipud(squeeze(scatRc(:,:,j,it))-scat)); colorbar
%         
%         title(['iterations for configuration ',num2str(j)])
%         figure(60+j);
%         subplot(1,2,1); plot(xs,scatRc(n/2,:,j,it)); hold all
%         subplot(1,2,2); plot(xs,scatRc(:,n/2,j,it)); hold all
%     end
%     figure(60+j);
%     subplot(1,2,1); plot(xs,scat(n/2,:)); title('cut at y=0'); hold all
%     subplot(1,2,2); plot(xs,scat(:,n/2)); title('cut at x=0'); hold all
%     
%     %--- display final reconstructions
%     figure(10);
%     subplot(3,nAvg,j); dispmat(M);
%     subplot(3,nAvg,nAvg+j); dispmat(squeeze(scatRc(:,:,j,nIter+1)));
%     subplot(3,nAvg,2*nAvg+j); plotConfig(thetas(indsIn(j)),thetas(indsOut(j)));
%     
% end %--- end for j
%  
% 
% scatRcAvg = mean(squeeze(scatRc(:,:,:,nIter+1)),3);
% %--- display averaged reconstruction
% figure(11);
% subplot(2,2,1);
% dispmat(scatRcAvg,'averaged reconstruction');
% subplot(2,2,2); dispmat(scat,'exact scattering')
% subplot(2,2,3); plot(xs,scatRcAvg(:,n/2),xs,scat(:,n/2),'-+')
% legend('reconstructed','exact'); title('cut at x=0')
% subplot(2,2,4); plot(xs,scatRcAvg(n/2,:),xs,scat(n/2,:),'-+')
% legend('reconstructed','exact'); title('cut at y=0')
% 
% figure(12);
% for j=1:nAvg,
%     subplot(2,nAvg+1,j); 
%     
%     dispmat(scatRc(:,:,j,nIter+1));
%     str = num2str(180/pi*(thetas(indsOut(j))-thetas(indsIn(j))),3);
%     title(['\Delta\theta = ',str,' deg; rel L2 error: ',num2str(scatErr(j,1))]);
%     
%     subplot(2,nAvg+1,nAvg+1+j);
%     contourf(flipud(abs(scatRc(:,:,j,nIter+1)-scat))); colorbar
%     
% end
% subplot(2,nAvg+1,nAvg+1);
% % scatErr = l1norm(scatRcAvg-scat)/l1norm(scat);
% scatErrAvg = norm(scatRcAvg-scat,'fro')/norm(scat,'fro');
% dispmat(scatRcAvg);
% title(['averaged reconstruction ; rel L2 error: ',num2str(scatErrAvg)]);
% 
% subplot(2,nAvg+1,2*nAvg+2);
% contourf(flipud(abs(scatRcAvg-scat))); colorbar

end
%----------------------------------------------------------------------

%======================================================================
function res = l1norm(mat)

res = sum(sum(abs(mat)));
end
%----------------------------------------------------------------------

%======================================================================
function plotConfig(thIn,thOut)

% lines of incoming and outgoing directions
plot([-cos(thIn),0],[-sin(thIn),0],'b', [cos(thOut),0],[sin(thOut),0],'g');
legend('\theta_{in}','\theta_{out}')
hold on

% unit circle
points = exp(i*2*pi*(0:1/100:1));
plot(real(points),imag(points),'r');
axis equal; axis([-1.2,1.2,-1.2,1.2]);

title('configuration')

end
%----------------------------------------------------------------------